@@ -4,7 +4,7 @@
 # Dominic Hargreaves / University of Oxford (c) 2007-2012
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.07";
+$Oxford::Calendar::VERSION = "2.08";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
@@ -619,7 +619,6 @@ Calendar:
     start: 19/01/2014
   Hilary 2015:
     start: 18/01/2015
-    provisional: 1
   Hilary 2016:
     start: 17/01/2016
     provisional: 1
@@ -629,6 +628,9 @@ Calendar:
   Hilary 2018:
     start: 14/01/2018
     provisional: 1
+  Hilary 2019:
+    start: 13/01/2019
+    provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
   Michaelmas 2002:
@@ -657,7 +659,6 @@ Calendar:
     start: 13/10/2013
   Michaelmas 2014:
     start: 12/10/2014
-    provisional: 1
   Michaelmas 2015:
     start: 11/10/2015
     provisional: 1
@@ -667,6 +668,9 @@ Calendar:
   Michaelmas 2017:
     start: 08/10/2017
     provisional: 1
+  Michaelmas 2018:
+    start: 07/10/2018
+    provisional: 1
   Trinity 2001:
     start: 22/04/2001
   Trinity 2002:
@@ -697,7 +701,6 @@ Calendar:
     start: 27/04/2014
   Trinity 2015:
     start: 26/04/2015
-    provisional: 1
   Trinity 2016:
     start: 24/04/2016
     provisional: 1
@@ -707,3 +710,6 @@ Calendar:
   Trinity 2018:
     start: 22/04/2018
     provisional: 1
+  Trinity 2019:
+    start: 28/04/2019
+    provisional: 1
